@@ -119,43 +119,43 @@ void LXQtPlatformTheme::loadSettings() {
     paletteChanged_ = false;
 
     QColor color = winColor_;
-    winColor_.setNamedColor(settings.value(QLatin1String("window_color"), QLatin1String("#efefef")).toString());
+    winColor_ = QColor::fromString(settings.value(QLatin1String("window_color"), QLatin1String("#efefef")).toString());
     if(!winColor_.isValid())
-        winColor_.setNamedColor(QStringLiteral("#efefef"));
+        winColor_ = QColor::fromString(QStringLiteral("#efefef"));
     paletteChanged_ = color != winColor_;
 
     color = baseColor_;
-    baseColor_.setNamedColor(settings.value(QLatin1String("base_color")).toString());
+    baseColor_ = QColor::fromString(settings.value(QLatin1String("base_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = baseColor_.isValid() && color != baseColor_;
 
     color = highlightColor_;
-    highlightColor_.setNamedColor(settings.value(QLatin1String("highlight_color")).toString());
+    highlightColor_ = QColor::fromString(settings.value(QLatin1String("highlight_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = highlightColor_.isValid() && color != highlightColor_;
 
     color = winTextColor_;
-    winTextColor_.setNamedColor(settings.value(QLatin1String("window_text_color")).toString());
+    winTextColor_ = QColor::fromString(settings.value(QLatin1String("window_text_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = winTextColor_.isValid() && color != winTextColor_;
 
     color = textColor_;
-    textColor_.setNamedColor(settings.value(QLatin1String("text_color")).toString());
+    textColor_ = QColor::fromString(settings.value(QLatin1String("text_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = textColor_.isValid() && color != textColor_;
 
     color = highlightedTextColor_;
-    highlightedTextColor_.setNamedColor(settings.value(QLatin1String("highlighted_text_color")).toString());
+    highlightedTextColor_ = QColor::fromString(settings.value(QLatin1String("highlighted_text_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = highlightedTextColor_.isValid() && color != highlightedTextColor_;
 
     color = linkColor_;
-    linkColor_.setNamedColor(settings.value(QLatin1String("link_color")).toString());
+    linkColor_ = QColor::fromString(settings.value(QLatin1String("link_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = linkColor_.isValid() && color != linkColor_;
 
     color = linkVisitedColor_;
-    linkVisitedColor_.setNamedColor(settings.value(QLatin1String("link_visited_color")).toString());
+    linkVisitedColor_ = QColor::fromString(settings.value(QLatin1String("link_visited_color")).toString());
     if (!paletteChanged_)
         paletteChanged_ = linkVisitedColor_.isValid() && color != linkVisitedColor_;
 
@@ -233,9 +233,13 @@ void LXQtPlatformTheme::loadSettings() {
 
     // SystemFont
     fontStr_ = settings.value(QLatin1String("font")).toString();
+
     if(!fontStr_.isEmpty()) {
-        if(font_.fromString(fontStr_))
-            QApplication::setFont(font_); // it seems that we need to do this manually.
+        if(font_.fromString(fontStr_)) {
+            if(qobject_cast<QApplication *>(QCoreApplication::instance())) {
+                QApplication::setFont(font_); // it seems that we need to do this manually.
+            }
+        }
     }
 
     // FixedFont
@@ -251,6 +255,14 @@ void LXQtPlatformTheme::loadSettings() {
     // keyboard
     cursorFlashTime_ = settings.value(QLatin1String("cursorFlashTime"));
     settings.endGroup();
+
+    // mouse cursor
+    QSettings sessionSettings(QSettings::UserScope, QLatin1String("lxqt"), QLatin1String("session"));
+    sessionSettings.beginGroup(QStringLiteral("Mouse"));
+    mouseCursorTheme_ = sessionSettings.value(QLatin1String("cursor_theme"));
+    int curSize = sessionSettings.value(QLatin1String("cursor_size"), 16).toInt();
+    mouseCursorSize_ = QSize(curSize, curSize);
+    sessionSettings.endGroup();
 }
 
 // this is called whenever the config file is changed.
@@ -285,24 +297,23 @@ void LXQtPlatformTheme::onSettingsChanged() {
 
     loadSettings(); // reload the config file
 
-    if(style_ != oldStyle || paletteChanged_) // the widget style or palette is changed
+    auto app = qobject_cast<QApplication *>(QCoreApplication::instance());
+
+    if(app && (style_ != oldStyle || paletteChanged_)) // the widget style or palette is changed
     {
-        // ask Qt5 to apply the new style
-        if(auto *app = qobject_cast<QApplication *>(QCoreApplication::instance()))
+        // ask Qt to apply the new style
+        QApplication::setStyle(style_);
+        // Qt 5.15 needs this and it's safe otherwise
+        if(LXQtPalette_ != nullptr)
         {
-            QApplication::setStyle(style_);
-            // Qt 5.15 needs this and it's safe otherwise
-            if(LXQtPalette_ != nullptr)
-            {
-                QApplication::setPalette(*LXQtPalette_);
-                // the app should be polished because the style may have an internal palette
-                QApplication::style()->polish(app);
-            }
+            QApplication::setPalette(*LXQtPalette_);
+            // the app should be polished because the style may have an internal palette
+            QApplication::style()->polish(app);
         }
     }
 
     if(iconTheme_ != oldIconTheme) { // the icon theme is changed
-        XdgIconLoader::instance()->updateSystemTheme(); // this is a private internal API of Qt5.
+        XdgIconLoader::instance()->updateSystemTheme(); // this is a private internal API of Qt.
     }
     XdgIconLoader::instance()->setFollowColorScheme(iconFollowColorScheme_);
 
@@ -321,18 +332,23 @@ void LXQtPlatformTheme::onSettingsChanged() {
         // FIXME: should we call the internal API: QApplicationPrivate::setFont() instead?
         // QGtkStyle does this internally.
         fixedFont_.fromString(fixedFontStr_); // FIXME: how to set this to the app?
-        if(font_.fromString(fontStr_))
-            QApplication::setFont(font_);
+        if(font_.fromString(fontStr_)) {
+            if(app) {
+                QApplication::setFont(font_);
+            }
+        }
     }
 
-    QApplication::setWheelScrollLines(wheelScrollLines_.toInt());
+    if(app) {
+        QApplication::setWheelScrollLines(wheelScrollLines_.toInt());
 
-    // emit a ThemeChange event to all widgets
-    const auto widgets = QApplication::allWidgets();
-    for(QWidget* const widget : widgets) {
-        // Qt5 added a QEvent::ThemeChange event.
-        QEvent event(QEvent::ThemeChange);
-        QApplication::sendEvent(widget, &event);
+        // emit a ThemeChange event to all widgets
+        const auto widgets = QApplication::allWidgets();
+        for(QWidget* const widget : widgets) {
+            // Qt5 added a QEvent::ThemeChange event.
+            QEvent event(QEvent::ThemeChange);
+            QApplication::sendEvent(widget, &event);
+        }
     }
 }
 
@@ -448,11 +464,9 @@ QVariant LXQtPlatformTheme::themeHint(ThemeHint hint) const {
     case KeyboardScheme:
         return QVariant(X11KeyboardScheme);
     case UiEffects:
-        break;
+        return QVariant(static_cast<int>(HoverEffect));
     case SpellCheckUnderlineStyle:
         break;
-    case TabAllWidgets:
-        break;
     case IconPixmapSizes:
         break;
     case PasswordMaskCharacter:
@@ -469,6 +483,10 @@ QVariant LXQtPlatformTheme::themeHint(ThemeHint hint) const {
         return wheelScrollLines_;
     case QPlatformTheme::ShowShortcutsInContextMenus:
         return QVariant(true);
+    case MouseCursorTheme:
+        return mouseCursorTheme_;
+    case MouseCursorSize:
+        return QVariant(mouseCursorSize_);
     default:
         break;
     }
