@@ -36,6 +36,7 @@
 #include <QString>
 #include <QFileSystemWatcher>
 #include <QFont>
+#include <QColor>
 
 class Q_GUI_EXPORT LXQtPlatformTheme : public QObject, public QPlatformTheme {
     Q_OBJECT
@@ -108,8 +109,12 @@ private:
     // mouse
     QVariant doubleClickInterval_;
     QVariant wheelScrollLines_;
+    // mouse cursor
+    QVariant mouseCursorTheme_;
+    QSize mouseCursorSize_;
     // keyboard
     QVariant cursorFlashTime_;
+
     QFileSystemWatcher *settingsWatcher_;
     QString settingsFile_;
 
